@@ -11,7 +11,7 @@ class Course(Base):
     name_of_class = 'courses'
 
     def __repr__(self):
-        return super().__repr__(['name','_id'])
+        return super().__repr__(['_id','name'])
 
     @classmethod
     def find_one_by_name(cls, the_name):
